==> ofono-0.42.tar.xz: ofono-0.42/drivers/isimodem/isimodem.h <==
/*
 *
 *  oFono - Open Source Telephony
 *
 *  Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

extern void isi_phonebook_init(void);
extern void isi_phonebook_exit(void);

extern void isi_devinfo_init(void);
extern void isi_devinfo_exit(void);

extern void isi_netreg_init(void);
extern void isi_netreg_exit(void);

extern void isi_voicecall_init(void);
extern void isi_voicecall_exit(void);

extern void isi_sms_init(void);
extern void isi_sms_exit(void);

extern void isi_cbs_init(void);
extern void isi_cbs_exit(void);

extern void isi_sim_init(void);
extern void isi_sim_exit(void);

extern void isi_ussd_init(void);
extern void isi_ussd_exit(void);

extern void isi_ssn_init(void);
extern void isi_ssn_exit(void);

extern void isi_call_forwarding_init(void);
extern void isi_call_forwarding_exit(void);

extern void isi_call_settings_init(void);
extern void isi_call_settings_exit(void);

extern void isi_call_barring_init(void);
extern void isi_call_barring_exit(void);

extern void isi_call_meter_init(void);
extern void isi_call_meter_exit(void);

extern void isi_radio_settings_init(void);
extern void isi_radio_settings_exit(void);

extern void isi_gprs_init(void);
extern void isi_gprs_exit(void);

extern void isi_gprs_context_init(void);
extern void isi_gprs_context_exit(void);

extern void isi_audio_settings_init(void);
extern void isi_audio_settings_exit(void);

==> ofono-0.53.tar.xz: ofono-0.53/drivers/isimodem/isimodem.h <==
/*
 *
 *  oFono - Open Source Telephony
 *
 *  Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

extern void isi_phonebook_init(void);
extern void isi_phonebook_exit(void);

extern void isi_devinfo_init(void);
extern void isi_devinfo_exit(void);

extern void isi_netreg_init(void);
extern void isi_netreg_exit(void);

extern void isi_voicecall_init(void);
extern void isi_voicecall_exit(void);

extern void isi_sms_init(void);
extern void isi_sms_exit(void);

extern void isi_cbs_init(void);
extern void isi_cbs_exit(void);

extern void isi_sim_init(void);
extern void isi_sim_exit(void);

extern void isi_ussd_init(void);
extern void isi_ussd_exit(void);

extern void isi_call_forwarding_init(void);
extern void isi_call_forwarding_exit(void);

extern void isi_call_settings_init(void);
extern void isi_call_settings_exit(void);

extern void isi_call_barring_init(void);
extern void isi_call_barring_exit(void);

extern void isi_call_meter_init(void);
extern void isi_call_meter_exit(void);

extern void isi_radio_settings_init(void);
extern void isi_radio_settings_exit(void);

extern void isi_gprs_init(void);
extern void isi_gprs_exit(void);

extern void isi_gprs_context_init(void);
extern void isi_gprs_context_exit(void);

extern void isi_audio_settings_init(void);
extern void isi_audio_settings_exit(void);

extern void isi_uicc_init(void);
extern void isi_uicc_exit(void);
